==> hornsey_1.0~20090727.orig.tar.gz: hornsey-1.0~20090727/src/hrn-image-player.h <==
#ifndef __HRN_IMAGE_PLAYER_H__
#define __HRN_IMAGE_PLAYER_H__

#include <clutter/clutter.h>


G_BEGIN_DECLS

#define HRN_TYPE_IMAGE_PLAYER                                           \
  (hrn_image_player_get_type ())
#define HRN_IMAGE_PLAYER(obj)                                           \
  (G_TYPE_CHECK_INSTANCE_CAST ((obj),                                  \
                               HRN_TYPE_IMAGE_PLAYER,                  \
                               HrnImagePlayer))
#define HRN_IMAGE_PLAYER_CLASS(klass)                                   \
  (G_TYPE_CHECK_CLASS_CAST ((klass),                                   \
                            HRN_TYPE_IMAGE_PLAYER,                     \
                            HrnImagePlayerClass))
#define IS_HRN_IMAGE_PLAYER(obj)                                        \
  (G_TYPE_CHECK_INSTANCE_TYPE ((obj),                                  \
                               HRN_TYPE_IMAGE_PLAYER))
#define IS_HRN_IMAGE_PLAYER_CLASS(klass)                                \
  (G_TYPE_CHECK_CLASS_TYPE ((klass),                                   \
                            HRN_TYPE_IMAGE_PLAYER))
#define HRN_IMAGE_PLAYER_GET_CLASS(obj)                                 \
  (G_TYPE_INSTANCE_GET_CLASS ((obj),                                   \
                              HRN_TYPE_IMAGE_PLAYER,                   \
                              HrnImagePlayerClass))

typedef struct _HrnImagePlayerPrivate HrnImagePlayerPrivate;
typedef struct _HrnImagePlayer HrnImagePlayer;
typedef struct _HrnImagePlayerClass HrnImagePlayerClass;

struct _HrnImagePlayer
{
  ClutterActor parent;

  HrnImagePlayerPrivate *priv;
};

struct _HrnImagePlayerClass
{
  ClutterActorClass parent_class;
};

GType hrn_image_player_get_type (void) G_GNUC_CONST;

G_END_DECLS

#endif /* __HRN_IMAGE_PLAYER_H__ */

==> hornsey_1.5.1.orig.tar.gz: hornsey-1.5.1/src/hrn-image-player.h <==
#ifndef __HRN_IMAGE_PLAYER_H__
#define __HRN_IMAGE_PLAYER_H__

#include <clutter/clutter.h>


G_BEGIN_DECLS

#define HRN_TYPE_IMAGE_PLAYER                                           \
  (hrn_image_player_get_type ())
#define HRN_IMAGE_PLAYER(obj)                                           \
  (G_TYPE_CHECK_INSTANCE_CAST ((obj),                                  \
                               HRN_TYPE_IMAGE_PLAYER,                  \
                               HrnImagePlayer))
#define HRN_IMAGE_PLAYER_CLASS(klass)                                   \
  (G_TYPE_CHECK_CLASS_CAST ((klass),                                   \
                            HRN_TYPE_IMAGE_PLAYER,                     \
                            HrnImagePlayerClass))
#define IS_HRN_IMAGE_PLAYER(obj)                                        \
  (G_TYPE_CHECK_INSTANCE_TYPE ((obj),                                  \
                               HRN_TYPE_IMAGE_PLAYER))
#define IS_HRN_IMAGE_PLAYER_CLASS(klass)                                \
  (G_TYPE_CHECK_CLASS_TYPE ((klass),                                   \
                            HRN_TYPE_IMAGE_PLAYER))
#define HRN_IMAGE_PLAYER_GET_CLASS(obj)                                 \
  (G_TYPE_INSTANCE_GET_CLASS ((obj),                                   \
                              HRN_TYPE_IMAGE_PLAYER,                   \
                              HrnImagePlayerClass))

typedef struct _HrnImagePlayerPrivate HrnImagePlayerPrivate;
typedef struct _HrnImagePlayer HrnImagePlayer;
typedef struct _HrnImagePlayerClass HrnImagePlayerClass;

struct _HrnImagePlayer
{
  ClutterGroup parent;

  HrnImagePlayerPrivate *priv;
};

struct _HrnImagePlayerClass
{
  ClutterGroupClass parent_class;
};

GType hrn_image_player_get_type (void) G_GNUC_CONST;

G_END_DECLS

#endif /* __HRN_IMAGE_PLAYER_H__ */
